==> visual-2.2.2-sources.jar: com/zhuge/analysis/util/ManifestUtils.java <==
package com.zhuge.analysis.util;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.util.Log;

import com.zhuge.analysis.stat.ZhugeSDK;

/**
 * 获取Manifest文件信息
 * Created by jiaokang on 15/11/9.
 */
public class ManifestUtils {


    /**
     * 获取包信息
     *
     * @param context
     * @return
     */
    public static PackageInfo getAppInfo(Context context) {
        PackageInfo appInfo = null;
        try {
            appInfo = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            Log.e(TAG, "获取应用名称失败");
        }
        return appInfo;
    }

    /**
     * 获取开发者配置信息
     *
     * @param context 应用上下文
     * @return AppKey 与Channel信息组成的字符串，若出错或未填写返回空字符串
     */
    public static String[] getDevInfo(Context context) {
        String[] devInfo;
        String ak;
        String cn;
        ApplicationInfo appInfo;
        try {
            appInfo = context.getPackageManager()
                    .getApplicationInfo(context.getPackageName(),
                            PackageManager.GET_META_DATA);
        } catch (PackageManager.NameNotFoundException e) {
            Log.e(TAG, "获取应用名称失败");
            return new String[]{"null", "null"};
        }
        ak = appInfo.metaData.get("ZHUGE_APPKEY") + "";
        cn = appInfo.metaData.get("ZHUGE_CHANNEL") + "";
        devInfo = new String[]{ak, cn};
        return devInfo;
    }

    private static final String TAG = "ZhugeSDK.Manifest";
}

==> visual-2.3.1-sources.jar: com/zhuge/analysis/util/ManifestUtils.java <==
package com.zhuge.analysis.util;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.util.Log;

import com.zhuge.analysis.stat.ZhugeSDK;

/**
 * 获取Manifest文件信息
 * Created by jiaokang on 15/11/9.
 */
public class ManifestUtils {


    /**
     * 获取包信息
     *
     * @param context
     * @return
     */
    public static PackageInfo getAppInfo(Context context) {
        PackageInfo appInfo = null;
        try {
            appInfo = context.getPackageManager().getPackageInfo(context.getPackageName(), 0);
        } catch (PackageManager.NameNotFoundException e) {
            Log.e(TAG, "获取应用名称失败");
        }
        return appInfo;
    }

    /**
     * 获取开发者配置信息
     *
     * @param context 应用上下文
     * @return AppKey 与Channel信息组成的字符串，若出错或未填写返回空字符串
     */
    public static String[] getDevInfo(Context context) {
        try {
            ApplicationInfo appInfo = context.getPackageManager()
                    .getApplicationInfo(context.getPackageName(),
                            PackageManager.GET_META_DATA);
            String ak = appInfo.metaData.get("ZHUGE_APPKEY") + "";
            String cn = appInfo.metaData.get("ZHUGE_CHANNEL") + "";
            String[] devInfo = new String[]{ak, cn};
            return devInfo;
        } catch (PackageManager.NameNotFoundException e) {
            Log.e(TAG, "获取应用名称失败");
            return new String[]{"null", "null"};
        }
    }

    private static final String TAG = "ZhugeSDK.Manifest";
}
